==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Ripristino del sistema, attendere prego..</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Ripristino fallito.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvio</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Aggiornamento fallito.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Aggiornamento fallito: è stato interrotto.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Aggiornamento fallito: errore DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Aggiornamento fallito: spazio su disco non sufficiente.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Sicuro di voler ripristinare da %1 a %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Annulla e riavvia</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.38.1.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Ripristino del sistema, attendere prego..</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Ripristino fallito.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvio</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Aggiornamento fallito.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Aggiornamento fallito: è stato interrotto.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Aggiornamento fallito: errore DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Aggiornamento fallito: spazio su disco non sufficiente.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Sicuro di voler ripristinare da %1 a %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Annulla e riavvia</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
</context>
</TS>
